@@ -1,3 +1,18 @@
+# Copyright Contributors to the Rez project
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+
 """
 Filesystem-related utilities.
 """
@@ -18,6 +33,7 @@ import os
 import re
 import stat
 import platform
+import uuid
 
 from rez.vendor.six import six
 from rez.utils.platform_ import platform_
@@ -383,32 +399,38 @@ def copy_or_replace(src, dst):
     '''
     try:
         shutil.copy(src, dst)
+        return
+
     except (OSError, IOError) as e:
         # It's possible that the file existed, but was owned by someone
         # else - in that situation, shutil.copy might then fail when it
         # tries to copy perms.
         # However, it's possible that we have write perms to the dir -
         # in which case, we can just delete and replace
-        import errno
+        #
+        if e.errno != errno.EPERM:
+            raise
 
-        if e.errno == errno.EPERM:
-            import tempfile
-            # try copying into a temporary location beside the old
-            # file - if we have perms to do that, we should have perms
-            # to then delete the old file, and move the new one into
-            # place
-            if os.path.isdir(dst):
-                dst = os.path.join(dst, os.path.basename(src))
+    # try copying into a temporary location beside the old file - if we have
+    # perms to do that, we should have perms to then delete the old file, and
+    # move the new one into place
+    #
+    if os.path.isdir(dst):
+        dst = os.path.join(dst, os.path.basename(src))
 
-            dst_dir, dst_name = os.path.split(dst)
-            dst_temp = tempfile.mktemp(prefix=dst_name + '.', dir=dst_dir)
-            shutil.copy(src, dst_temp)
-            if not os.path.isfile(dst_temp):
-                raise RuntimeError(
-                    "shutil.copy completed successfully, but path"
-                    " '%s' still did not exist" % dst_temp)
-            os.remove(dst)
-            shutil.move(dst_temp, dst)
+    dst_dir, dst_name = os.path.split(dst)
+    tmp_filename = ".%s.%s" % (uuid.uuid4().hex, dst_name)
+    dst_temp = os.path.join(dst_dir, tmp_filename)
+
+    shutil.copy(src, dst_temp)
+
+    if not os.path.isfile(dst_temp):
+        raise RuntimeError(
+            "shutil.copy completed successfully, but path"
+            " '%s' still did not exist" % dst_temp
+        )
+    os.remove(dst)
+    shutil.move(dst_temp, dst)
 
 
 def copytree(src, dst, symlinks=False, ignore=None, hardlinks=False):
@@ -686,19 +708,3 @@ def windows_long_path(dos_path):
         path = "\\\\?\\" + path
 
     return path
-
-
-# Copyright 2013-2016 Allan Johns.
-#
-# This library is free software: you can redistribute it and/or
-# modify it under the terms of the GNU Lesser General Public
-# License as published by the Free Software Foundation, either
-# version 3 of the License, or (at your option) any later version.
-#
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this library.  If not, see <http://www.gnu.org/licenses/>.
